package org.jenkinsci.plugins.p4_client.credentials;

import hudson.Util;

import org.kohsuke.stapler.export.Exported;

import com.cloudbees.plugins.credentials.CredentialsScope;
import com.cloudbees.plugins.credentials.common.IdCredentials;
import com.cloudbees.plugins.credentials.common.StandardCredentials;

import edu.umd.cs.findbugs.annotations.CheckForNull;
import edu.umd.cs.findbugs.annotations.NonNull;

public abstract class P4StandardCredentials extends P4Credentials implements
		StandardCredentials {

	private static final long serialVersionUID = 1L;

	@NonNull
	private final String id;

	@NonNull
	private final String description;

	/**
	 * Constructor.
	 * 
	 * @param id
	 *            the id.
	 * @param description
	 *            the description.
	 */
	public P4StandardCredentials(@CheckForNull String id,
			@CheckForNull String description) {
		super();
		this.id = IdCredentials.Helpers.fixEmptyId(id);
		this.description = Util.fixNull(description);
	}

	/**
	 * Constructor.
	 * 
	 * @param scope
	 *            the scope.
	 * @param id
	 *            the id.
	 * @param description
	 *            the description.
	 */
	public P4StandardCredentials(@CheckForNull CredentialsScope scope,
			@CheckForNull String id, @CheckForNull String description) {
		super(scope);
		this.id = IdCredentials.Helpers.fixEmptyId(id);
		this.description = Util.fixNull(description);
	}

	@NonNull
	public String getDescription() {
		return description;
	}

	@NonNull
	@Exported
	public String getId() {
		return id;
	}

	@Override
	public final boolean equals(Object o) {
		return IdCredentials.Helpers.equals(this, o);
	}

	@Override
	public final int hashCode() {
		return IdCredentials.Helpers.hashCode(this);
	}

}
